==> krita-debuginfo-3.3.2.1-1.tar.xz: usr/src/debug/krita-3.3.2.1-1/plugins/tools/tool_polygon/qrc_tool_polygon.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/krita/krita-3.3.2.1-1.x86_64/src/krita-3.3.2.1/plugins/tools/tool_polygon/tool_polygon_cursor.png
  0x0,0x0,0x1,0x20,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x20,0x0,0x0,0x0,0x20,0x4,0x3,0x0,0x0,0x0,0x81,0x54,0x67,0xc7,
  0x0,0x0,0x0,0x21,0x50,0x4c,0x54,0x45,0x0,0x0,0x0,0xc6,0xc6,0xc6,0xfd,0xfd,
  0xfd,0xff,0xff,0xff,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0xef,0xef,
  0xff,0xff,0xff,0x0,0x0,0x0,0xff,0xff,0xff,0xe4,0x5c,0xcd,0xb0,0x0,0x0,0x0,
  0x9,0x74,0x52,0x4e,0x53,0x0,0x0,0x1,0x1,0x2,0x2,0x4,0x8,0x8,0xf,0x8d,
  0x72,0xbd,0x0,0x0,0x0,0xa5,0x49,0x44,0x41,0x54,0x78,0xda,0xa5,0xd0,0x31,0xa,
  0x3,0x21,0x10,0x5,0xd0,0x1,0xab,0xdd,0x6a,0x6d,0x53,0xe6,0x4,0xb2,0x9f,0x84,
  0x60,0xbb,0x47,0xc9,0x85,0x4c,0x39,0x56,0xb,0x16,0x41,0x4f,0x99,0x41,0xcc,0x8e,
  0x41,0x52,0x84,0x8,0x82,0x3e,0xbe,0xce,0x28,0x11,0xcd,0x91,0xfa,0x31,0x82,0x3d,
  0x45,0xbb,0xfc,0x4,0xa5,0xec,0x8b,0x4c,0x5,0xe6,0x87,0x65,0xe,0x43,0xe2,0x9f,
  0x2a,0xda,0x69,0xf9,0x0,0x3,0xcf,0x5,0x58,0xcf,0xae,0x92,0xec,0x91,0x89,0xcb,
  0xa,0x1c,0xe0,0x3,0x11,0xeb,0x29,0x23,0x1,0xaa,0x62,0x1a,0x48,0xa0,0x49,0x83,
  0xdc,0x16,0xfc,0x6c,0x85,0x8e,0xb7,0xb4,0xcf,0xca,0xf4,0x1d,0x86,0x23,0x7a,0xe9,
  0x8,0x53,0xa8,0xa0,0x7d,0xc4,0x2c,0xb8,0x6b,0xa7,0x53,0x12,0xed,0x21,0x2,0xb9,
  0x83,0x99,0xd3,0xd,0x3e,0xbc,0x61,0x83,0x2b,0xb8,0x4a,0x44,0x13,0xc0,0x45,0xc0,
  0x47,0xa7,0x0,0xdc,0x81,0xd4,0x83,0x24,0x64,0xf9,0x2,0x2,0xce,0x40,0x83,0x8e,
  0xc,0x58,0x53,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // tool_polygon_cursor.png
  0x0,0x17,
  0x0,0xfd,0xc0,0xe7,
  0x0,0x74,
  0x0,0x6f,0x0,0x6f,0x0,0x6c,0x0,0x5f,0x0,0x70,0x0,0x6f,0x0,0x6c,0x0,0x79,0x0,0x67,0x0,0x6f,0x0,0x6e,0x0,0x5f,0x0,0x63,0x0,0x75,0x0,0x72,0x0,0x73,
  0x0,0x6f,0x0,0x72,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/tool_polygon_cursor.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x7c,0x2c,0x70,0x40,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_tool_polygon)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_tool_polygon)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_tool_polygon)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_tool_polygon)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_tool_polygon)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_tool_polygon)(); }
   } dummy;
}

==> krita-debuginfo-3.3.3-1.tar.xz: usr/src/debug/krita-3.3.3-1/plugins/tools/tool_polygon/qrc_tool_polygon.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/krita/krita-3.3.3-1.i686/src/krita-3.3.3/plugins/tools/tool_polygon/tool_polygon_cursor.png
  0x0,0x0,0x1,0x20,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x20,0x0,0x0,0x0,0x20,0x4,0x3,0x0,0x0,0x0,0x81,0x54,0x67,0xc7,
  0x0,0x0,0x0,0x21,0x50,0x4c,0x54,0x45,0x0,0x0,0x0,0xc6,0xc6,0xc6,0xfd,0xfd,
  0xfd,0xff,0xff,0xff,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0xef,0xef,
  0xff,0xff,0xff,0x0,0x0,0x0,0xff,0xff,0xff,0xe4,0x5c,0xcd,0xb0,0x0,0x0,0x0,
  0x9,0x74,0x52,0x4e,0x53,0x0,0x0,0x1,0x1,0x2,0x2,0x4,0x8,0x8,0xf,0x8d,
  0x72,0xbd,0x0,0x0,0x0,0xa5,0x49,0x44,0x41,0x54,0x78,0xda,0xa5,0xd0,0x31,0xa,
  0x3,0x21,0x10,0x5,0xd0,0x1,0xab,0xdd,0x6a,0x6d,0x53,0xe6,0x4,0xb2,0x9f,0x84,
  0x60,0xbb,0x47,0xc9,0x85,0x4c,0x39,0x56,0xb,0x16,0x41,0x4f,0x99,0x41,0xcc,0x8e,
  0x41,0x52,0x84,0x8,0x82,0x3e,0xbe,0xce,0x28,0x11,0xcd,0x91,0xfa,0x31,0x82,0x3d,
  0x45,0xbb,0xfc,0x4,0xa5,0xec,0x8b,0x4c,0x5,0xe6,0x87,0x65,0xe,0x43,0xe2,0x9f,
  0x2a,0xda,0x69,0xf9,0x0,0x3,0xcf,0x5,0x58,0xcf,0xae,0x92,0xec,0x91,0x89,0xcb,
  0xa,0x1c,0xe0,0x3,0x11,0xeb,0x29,0x23,0x1,0xaa,0x62,0x1a,0x48,0xa0,0x49,0x83,
  0xdc,0x16,0xfc,0x6c,0x85,0x8e,0xb7,0xb4,0xcf,0xca,0xf4,0x1d,0x86,0x23,0x7a,0xe9,
  0x8,0x53,0xa8,0xa0,0x7d,0xc4,0x2c,0xb8,0x6b,0xa7,0x53,0x12,0xed,0x21,0x2,0xb9,
  0x83,0x99,0xd3,0xd,0x3e,0xbc,0x61,0x83,0x2b,0xb8,0x4a,0x44,0x13,0xc0,0x45,0xc0,
  0x47,0xa7,0x0,0xdc,0x81,0xd4,0x83,0x24,0x64,0xf9,0x2,0x2,0xce,0x40,0x83,0x8e,
  0xc,0x58,0x53,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // tool_polygon_cursor.png
  0x0,0x17,
  0x0,0xfd,0xc0,0xe7,
  0x0,0x74,
  0x0,0x6f,0x0,0x6f,0x0,0x6c,0x0,0x5f,0x0,0x70,0x0,0x6f,0x0,0x6c,0x0,0x79,0x0,0x67,0x0,0x6f,0x0,0x6e,0x0,0x5f,0x0,0x63,0x0,0x75,0x0,0x72,0x0,0x73,
  0x0,0x6f,0x0,0x72,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/tool_polygon_cursor.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x60,0xd5,0x9a,0x8d,0xa0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_tool_polygon)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_tool_polygon)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_tool_polygon)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_tool_polygon)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_tool_polygon)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_tool_polygon)(); }
   } dummy;
}
